@@ -483,6 +483,7 @@ public:
     static unsigned uid;
     static const char *sipusers;
     static const char *sipadmin;
+    static int exit_code;
 
     server(const char *id);
 
@@ -780,5 +781,34 @@ public:
 };
 #endif
 
+#ifdef  HAVE_SYS_INOTIFY_H
+
+class __LOCAL notify : private JoinableThread
+{
+private:
+    notify();
+
+    ~notify();
+
+    void run(void);
+
+    static notify thread;
+
+public:
+    static void start(void);
+    static void stop(void);
+};
+
+#else
+
+class __LOCAL notify
+{
+public:
+    static void start(void);
+    static void stop(void);
+};
+
+#endif
+
 END_NAMESPACE
 
